package com.zipcodewilmington.gildedrose;

import org.junit.Assert;
import org.junit.Test;

public class InventoryTest {

    @Test
    public void testAdjustItem(){
        Item agedBrie = new Item("Aged Brie", 10, 30);
        Item backstagePasses = new Item("Backstage passes to a TAFKAL80ETC concert", 10, 30);
        Item sulfuras = new Item("Sulfuras, Hand of Ragnaros", 10, 80);
        Item[] expected = {agedBrie, backstagePasses, sulfuras};

        Item[] actual = expected;



        Assert.assertEquals(expected, actual);
    }


    @Test
    public void testSulfurasHandler() {
        Item agedBrie = new Item("Aged Brie", 10, 30);
        Item backstagePasses = new Item("Backstage passes to a TAFKAL80ETC concert", 10, 30);
        Item sulfuras = new Item("Sulfuras, Hand of Ragnaros", 10, 80);
        Item[] item = {agedBrie, backstagePasses, sulfuras};
        Inventory inv = new Inventory(item);
        int before = sulfuras.getQuality();
        int expected = before;

        int actual = before;

        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testAgedBrieHandler() {
        // given
        Item agedBrie = new Item("Aged Brie", 10, 30);
        Item backstagePasses = new Item("Backstage passes to a TAFKAL80ETC concert", 10, 30);
        Item sulfuras = new Item("Sulfuras, Hand of Ragnaros", 10, 80);
        Item[] item = {agedBrie, backstagePasses, sulfuras};
        Inventory inv = new Inventory(item);
        int expected = agedBrie.getQuality() + 1;

        // when
        inv.adjustItemQuality(agedBrie, 1);
        int actual= agedBrie.getQuality();


        //then
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testBackstagePassesHandler(){
        // given
        Item agedBrie = new Item("Aged Brie", 10, 30);
        Item backstagePasses = new Item("Backstage passes to a TAFKAL80ETC concert", 10, 30);
        Item sulfuras = new Item("Sulfuras, Hand of Ragnaros", 10, 80);
        Item[] item = {agedBrie, backstagePasses, sulfuras};
        Inventory inv = new Inventory(item);
        int expected = backstagePasses.getQuality() + 2;

        //when
        inv.adjustItemQuality(backstagePasses, 2);
        int actual = backstagePasses.getQuality();

        //then
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testIsMaxQuality(){
        //given
        Item agedBrie = new Item("Aged Brie", 10, 50);
        Item backstagePasses = new Item("Backstage passes to a TAFKAL80ETC concert", 10, 50);
        Item[] item = {agedBrie, backstagePasses};
        Inventory inv = new Inventory(item);


        Assert.assertTrue(inv.isMaxQuality(50));
    }

    @Test
    public void testItemisExpired(){
        Item agedBrie = new Item("Aged Brie", 0, 50);
        Item backstagePasses = new Item("Backstage passes to a TAFKAL80ETC concert", 0, 50);
        Item[] item = {agedBrie, backstagePasses};
        Inventory inv = new Inventory(item);

        Assert.assertTrue(inv.itemIsExpired(agedBrie));
    }

    @Test
    public void testAdjustItemSellIn(){
        Item agedBrie = new Item("Aged Brie", 1, 50);
        Item backstagePasses = new Item("Backstage passes to a TAFKAL80ETC concert", 1, 50);
        Item sulfuras = new Item("Sulfuras, Hand of Ragnaros", 1, 80);
        Item[] item = {agedBrie, backstagePasses, sulfuras};
        Inventory inv = new Inventory(item);

        inv.adjustItemSellIn(agedBrie);

        Assert.assertTrue(inv.itemIsExpired(agedBrie));
    }

}

